SpecializationUtil.registerSpecialization("whAutomation", "whAutomation", g_currentModDirectory.."whAutomation.lua");

-- help line part here
function InputBinding.getKeysNamesOfDigitalAction(actionIndex)
    local actionData = InputBinding.actions[actionIndex];
    local k1, k2, m1 = nil;
    if #actionData.keys1 > 0 then
        k1 = InputBinding.getKeyNames(actionData.keys1);
    end
    if #actionData.keys2 > 0 then
        k2 = InputBinding.getKeyNames(actionData.keys2);
    end
    if #actionData.mouseButtons > 0 then
        m1 = InputBinding.getMouseButtonNames(actionData.mouseButtons);
    end
    if k1 ~= nil and k2 ~= nil then
        return string.format("%s %s %s", k1, g_i18n:getText("ui_and"), k2);
    end
    if k1 ~= nil then
        return k1;
    end
    if k2 ~= nil then
        return k2;
    end
    if m1 ~= nil then
        return m1
    end
    return "";
end

function InputBinding.getMouseButtonNames(mouseButtons)
    return g_i18n:getText("ui_mouse") .. " " .. MouseHelper.getButtonNames(mouseButtons);
end

function loadHelpLine(xml, helpLineCategories, helpLineCategorySelectorElement, modDirectory)
    xml = loadXMLFile("customHelpLineViewContentXML", xml);
    local categoriesIndex = 0;
    while true do
        local categoryQuery = string.format("helpLines.helpLineCategory(%d)", categoriesIndex);
        if not hasXMLProperty(xml, categoryQuery) then
            break;
        end
        local category = {
            title = getXMLString(xml, string.format("%s#title", categoryQuery)),
            helpLines = {}
        };
        helpLineCategorySelectorElement:addText(g_i18n:getText(category.title));
        local helpLinesIndex = 0;
        while true do
            local helpLineQuery = string.format("%s.helpLine(%d)", categoryQuery, helpLinesIndex);
            if not hasXMLProperty(xml, helpLineQuery) then
                break;
            end
            local helpLine = {
                title = getXMLString(xml, string.format("%s#title", helpLineQuery)),
                items = {}
            };
            local itemsIndex = 0;
            while true do
                local itemQuery = string.format("%s.item(%d)", helpLineQuery, itemsIndex);
                if not hasXMLProperty(xml, itemQuery) then
                    break;
                end
                local itemType = getXMLString(xml, string.format("%s#type", itemQuery));
                local itemValue = getXMLString(xml, string.format("%s#value", itemQuery));
                if itemType == "image" then
                    itemValue = modDirectory .. itemValue;
                end
                if (itemType == "text" or itemType == "image") and itemValue ~= nil then
                    table.insert(helpLine.items, {
                        type = itemType,
                        value = itemValue,
                        heightScale = Utils.getNoNil(getXMLFloat(xml, string.format("%s#heightScale", itemQuery)), 1)
                    });
                end
                itemsIndex = itemsIndex + 1;
            end
            table.insert(category.helpLines, helpLine);
            helpLinesIndex = helpLinesIndex + 1;
        end
        table.insert(helpLineCategories, category);
        categoriesIndex = categoriesIndex + 1;
    end
    delete(xml);
end

for k, v in pairs(g_i18n.texts) do
    local nv = v;
    for m in nv:gmatch("$input_.-;") do
        local input = m:gsub("$input_", ""):gsub(";", "");
        nv = nv:gsub(m, InputBinding.getKeysNamesOfDigitalAction(InputBinding[input]));
    end
    g_i18n.globalI18N:setText(k, nv);
end

loadHelpLine(g_currentModDirectory .. "helpline/helpLine.xml", g_inGameMenu.helpLineCategories, g_inGameMenu.helpLineCategorySelectorElement, g_currentModDirectory);
-- help line end here


whAutomation_Register = {};

g_i18n.globalI18N.texts["whAutomation"] = g_i18n:getText("whAutomation"); 

local version = SpecializationUtil.getSpecialization("whAutomation").Version;

function whAutomation_Register:loadMap(name)
	if self.firstRun == nil then
		self.firstRun = false;
		print("--- loading whAutomation ver. "..string.format("%1.2f",version).." by fcelsa (Team FSI Modding)");
		
		for k, v in pairs(VehicleTypeUtil.vehicleTypes) do
			if v ~= nil then
				local allowInsertion = true;
				for i = 1, table.maxn(v.specializations) do
					local vs = v.specializations[i];
					if vs ~= nil and vs == SpecializationUtil.getSpecialization("woodHarvester") then
						local v_name_string = v.name;
						local point_location = string.find(v_name_string, ".", nil, true);
						if point_location ~= nil then
							local _name = string.sub(v_name_string, 1, point_location-1);
							if rawget(SpecializationUtil.specializations, string.format("%s.whAutomation", _name)) ~= nil then
								allowInsertion = false;								
							end
						end
						if allowInsertion then	
							table.insert(v.specializations, SpecializationUtil.getSpecialization("whAutomation"));
						end
					end
				end
			end
		end
	end
end

function whAutomation_Register:deleteMap()
end

function whAutomation_Register:keyEvent(unicode, sym, modifier, isDown)
end

function whAutomation_Register:mouseEvent(posX, posY, isDown, isUp, button)
end

function whAutomation_Register:update(dt)
end

function whAutomation_Register:draw()
end

addModEventListener(whAutomation_Register);
